'**********************************************************
'Compiler            : BasCom
'Hardware            : Ansteuerung von Funksteckdosen
'Chip type           : ATmega8 (und 74HCT4066)
'Clock frequency     : 8,000000 MHz
'
'RoBue, 19.01.2009
'**********************************************************

$regfile = "m8def.dat"
$crystal = 8000000

' Es werden 4 Leitungen abgefragt (PORTD4-7),
' ob ein Pegelwechsel stattgefunden hat.
' Wenn Ja, wird dieser als kurzer Impuls (500ms)
' an einen Pin von PORTC/PORTB ausgegeben.
' Damit werden 74HCT4066-Bausteine angesteuert,
' die einen Tastendruck des Handsenders simulieren.
' -> http://forum.mikrokopter.de/topic-395.html


' Ex -> Eingang
E1 Alias Pind.4
E2 Alias Pind.5
E3 Alias Pind.6
E4 Alias Pind.7

' Axy -> Ausgang
' x: 1-4 -> Eingang 1-4 zugeordnet
' y: e -> Port zum Einschalten, a -> Port zum Ausschalten
' -> E1:
A1e Alias Portb.1
A1a Alias Portb.2
' -> E2:
A2e Alias Portb.3
A2a Alias Portb.4
' -> E3:
A3e Alias Portc.0
A3a Alias Portc.1
' -> E4:
A4e Alias Portc.2
A4a Alias Portc.3

' Port fuer Eingabe
Config E1 = Input
Config E2 = Input
Config E3 = Input
Config E4 = Input
' Pullup ein
Portd.4 = 1
Portd.5 = 1
Portd.6 = 1
Portd.7 = 1

' Port zur Ausgabe (Schaltimpuls)
Config Pinc.0 = Output
Config Pinc.1 = Output
Config Pinc.2 = Output
Config Pinc.3 = Output
Config Pinb.1 = Output
Config Pinb.2 = Output
Config Pinb.3 = Output
Config Pinb.4 = Output

Dim Eingang(4) As Byte
Dim I As Byte
Dim Test As Byte

' PROGRAMM:
' --------

' Initialisierung
' ---------------

' Zuruecksetzen des Eingabebuffers -> alles low
For I = 1 To 4
Eingang(i) = 0
Next I

' Alles ausschalten
A1e = 0
A1a = 1
Waitms 500
A1a = 0

A2e = 0
A2a = 1
Waitms 500
A2a = 0

A3e = 0
A3a = 1
Waitms 500
A3a = 0

A4e = 0
A4a = 1
Waitms 500
A4a = 0


' Schleife
' --------

Do

Test = E1
If Test <> Eingang(1) Then
   If Test = 1 Then
      A1e = 1
      Waitms 500
      A1e = 0
      Eingang(1) = 1
   Else
      A1a = 1
      Waitms 500
      A1a = 0
      Eingang(1) = 0
   End If
End If

Test = E2
If Test <> Eingang(2) Then
   If Test = 1 Then
      A2e = 1
      Waitms 500
      A2e = 0
      Eingang(2) = 1
   Else
      A2a = 1
      Waitms 500
      A2a = 0
      Eingang(2) = 0
   End If
End If

Test = E3
If Test <> Eingang(3) Then
   If Test = 1 Then
      A3e = 1
      Waitms 500
      A3e = 0
      Eingang(3) = 1
   Else
      A3a = 1
      Waitms 500
      A3a = 0
      Eingang(3) = 0
   End If
End If

Test = E4
If Test <> Eingang(4) Then
   If Test = 1 Then
      A4e = 1
      Waitms 500
      A4e = 0
      Eingang(4) = 1
   Else
      A4a = 1
      Waitms 500
      A4a = 0
      Eingang(4) = 0
   End If
End If

Loop